/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license2.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is James A. Overton's code (james@overton.ca).
 *
 * The Initial Developer of the Original Code is James A. Overton.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *	James A. Overton <james@overton.ca>
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * @fileoverview An old-style installer script for installing the Mozile Extension if Mozilla.
 * ACKNOWLEDGEMENTS:
 * I have adapted this file from Chris Pederick's Web Devloper 0.3 extension for Firebird, and I am very grateful to him.
 * See http://chrispederick.myacen.com/work/firebird/webdeveloper/
 * @link http://mozile.mozdev.org 
 * @author James A. Overton <james@overton.ca>
 * @version 0.7
 */

	// Set Global Variables
	
	// This has to be set manually: JAR to install an archive, and DIR to install a directory
var installType	= "JAR";

var author              = "mozile.mozdev.org";
var displayName         = "Mozile Editor";
var name                = "mozile";
var version             = "0.7.6";
var error               = null;
var jarName             = name + ".jar";

var contentFolder				= "content/";
var localeFolder				= "locale/en-US/";
var skinFolder					= "skin/";


initInstall(displayName, name, version);

	// Check for current installation
	// Check for a JAR installation first
var jarExistsInApplication = File.exists(getFolder(getFolder("chrome"), jarName));
var jarExistsInProfile     = File.exists(getFolder(getFolder("Profile", "chrome"), jarName));	
	// Now check for a DIR installation
var dirExistsInApplication = File.exists(getFolder(getFolder("chrome"), name));
var dirExistsInProfile     = File.exists(getFolder(getFolder("Profile", "chrome"), name));

//alert(jarExistsInApplication +":"+ jarExistsInProfile +":"+ dirExistsInApplication +":"+ dirExistsInProfile);

	// If this is a JAR installer, do lots of stuff
if(installType=="JAR") {
	//alert("Starting JAR Install");
	
		// If there is already a directory installation, warn and quit (We can't convert yet)
	if(dirExistsInApplication || dirExistsInProfile) {
		error = "This installer is for the stable branch of Mozile, but your environment is configured for the development branch. Installation cannot proceed!\n See http://mozile.mozdev.org/docs/mozileDevelopment.html for information on converting between the stable and development branches.";
		alert(error);
		cancelInstall(error); 
	}
	
		// If there is no DIR installation, go ahead and install
	else {
			// If there is no previous installation, ask where to install
			// Otherwise overwrite the old installation
		if(!jarExistsInApplication && !jarExistsInProfile) {
			var message = "Where would you like to install Mozile?\n OK = Install in your user profile, protecting Mozile when the browser is upgraded,\n Cancel = Install in the application folder, allowing everyone to use Mozile.";
			var yes = confirm(message);
			if(yes) {
				jarExistsInProfile = true;
			}
			else {
				jarExistsInApplication = true;
			}
		}
		
		//alert(jarExistsInApplication +":"+ jarExistsInProfile);
		
		if(jarExistsInApplication) {    
			var contentFlag = CONTENT | DELAYED_CHROME;
			var localeFlag  = LOCALE | DELAYED_CHROME;
			var skinFlag    = SKIN | DELAYED_CHROME;
			var folder      = getFolder("chrome");
		}
		else {
			var contentFlag         = CONTENT | PROFILE_CHROME;
			var localeFlag          = LOCALE | PROFILE_CHROME;
			var skinFlag            = SKIN | PROFILE_CHROME;
			var folder              = getFolder("Profile", "chrome");
		}
		
		setPackageFolder(folder);
		error = addFile(author, version, "chrome/" + jarName, folder, null);
	
		folder = getFolder(folder, jarName);
		registerChrome(contentFlag, folder, contentFolder);
		registerChrome(localeFlag, folder, localeFolder);
		registerChrome(skinFlag, folder, skinFolder);
		
		error = performInstall();
		if(error != SUCCESS && error != 999)
		{
			alert("The installation of the extension failed.\n" + error);
			cancelInstall(error);
		}
			// If it succeeded
		else {
			alert("The extension installed successfully! Please restart your browser.");
		}
		doneFlag=true;
		cancelInstall(error);
	}
}

	// if this is not a JAR installer
else {
	//alert("Starting DIR Install");
	
		// If there is a JAR installation, warn and quit (We can't convert yet)
	if(jarExistsInApplication || jarExistsInProfile) {
		error = "This installer is for the development branch of Mozile, but your environment is configured for the stable branch. Installation cannot proceed!\n See http://mozile.mozdev.org/docs/mozileDevelopment.html for information on converting between the stable and development branches.";
		alert(error);
		cancelInstall(error); 
	}
	
		// If there is no JAR file, go ahead and install
	else {
	
			// If there is no previous installation, ask where Mozile should be installed
			// Otherwise just overwrite the old installation
		if(!dirExistsInApplication && !dirExistsInProfile) {
			var message = "Where would you like to install Mozile?\n OK = Install in your user profile, protecting Mozile when the browser is upgraded,\n Cancel = Install in the application folder, allowing everyone to use Mozile";
			var yes = confirm(message);
			if(yes) {
				dirExistsInProfile = true;
			}
			else {
				dirExistsInApplication = true;
			}
		}
		
		if(dirExistsInApplication) {    
			var contentFlag = CONTENT | DELAYED_CHROME;
			var localeFlag  = LOCALE | DELAYED_CHROME;
			var skinFlag    = SKIN | DELAYED_CHROME;
			var chrome      = getFolder("chrome");
			var folder			= getFolder(chrome,name);
		}
		else {
			var contentFlag		= CONTENT | PROFILE_CHROME;
			var localeFlag		= LOCALE | PROFILE_CHROME;
			var skinFlag			= SKIN | PROFILE_CHROME;
			var chrome				= getFolder("Profile", "chrome");
			var folder				= getFolder(chrome,name);
		}
		
		//alert(contentFlag +":"+ localeFlag +":"+ skinFlag +":"+ folder);
		
		setPackageFolder(folder);
		error = addDirectory("", "chrome/"+name, folder, "");
		
		registerChrome(contentFlag, folder, contentFolder);
		registerChrome(localeFlag, folder, localeFolder);
		registerChrome(skinFlag, folder, skinFolder);
		
		error = performInstall();
		if(error != SUCCESS && error != 999)
		{
			alert("The installation of the extension failed.\n" + error);
			cancelInstall(error);
		}
			// If it succeeded
		else {
			alert("The extension installed successfully! Please restart your browser.");
		}
		cancelInstall(error);
	
	}
	
}


